# Manus

Manus is a utilities namesapce package.  It is designed to provide generic utility classes, implement design patterns that are genrically useful, and to provide a namespace to add on / polyfill other packages